@@ -17,7 +17,7 @@ use Data::Dumper qw/Dumper/;
 use English qw/ -no_match_vars /;
 
 
-our $VERSION     = version->new('0.3.5');
+our $VERSION     = version->new('0.3.6');
 our @EXPORT_OK   = qw//;
 our %EXPORT_TAGS = ();
 #our @EXPORT      = qw//;
@@ -41,12 +41,11 @@ __END__
 
 =head1 NAME
 
-Tail::Tool::PostProcess - The parent module for plugins that change individual
-lines. eg highlighting
+Tail::Tool::PostProcess - The parent module for plugins that change individual lines. eg highlighting
 
 =head1 VERSION
 
-This documentation refers to Tail::Tool::PostProcess version 0.3.5.
+This documentation refers to Tail::Tool::PostProcess version 0.3.6.
 
 =head1 SYNOPSIS
 
